@@ -39,7 +39,7 @@ import codecs
 import sys
 
 __copyright__ = (
-    "Copyright 2005-2012 Canonical Ltd.\n" "Copyright 2017-2022 Breezy developers"
+    "Copyright 2005-2012 Canonical Ltd.\nCopyright 2017-2025 Breezy developers"
 )
 
 # same format as sys.version_info: "A tuple containing the five components of
@@ -49,7 +49,7 @@ __copyright__ = (
 # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
 # releaselevel of 'dev' for unreleased under-development code.
 
-version_info = (3, 3, 9, "final", 0)
+version_info = (3, 3, 15, "final", 0)
 
 
 def _format_version_tuple(version_info):
@@ -81,9 +81,9 @@ def _format_version_tuple(version_info):
     1.4.0.wibble.0
     """
     if len(version_info) == 2:
-        main_version = "%d.%d" % version_info[:2]
+        main_version = f"{version_info[0]}.{version_info[1]}"
     else:
-        main_version = "%d.%d.%d" % version_info[:3]
+        main_version = f"{version_info[0]}.{version_info[1]}.{version_info[2]}"
     if len(version_info) <= 3:
         return main_version
 
@@ -100,7 +100,7 @@ def _format_version_tuple(version_info):
         sub_string = ".dev" + str(sub)
     elif release_type in ("alpha", "beta"):
         if version_info[2] == 0:
-            main_version = "%d.%d" % version_info[:2]
+            main_version = f"{version_info[0]}.{version_info[1]}"
         sub_string = "." + release_type[0] + str(sub)
     elif release_type == "candidate":
         sub_string = ".rc" + str(sub)
@@ -116,7 +116,7 @@ _core_version_string = ".".join(map(str, version_info[:3]))
 
 
 def _patch_filesystem_default_encoding(new_enc):
-    """Change the Python process global encoding for filesystem names
+    """Change the Python process global encoding for filesystem names.
 
     The effect is to change how open() and other builtin functions handle
     unicode filenames on posix systems. This should only be done near startup.
