@@ -15,22 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
 import fastbencode as bencode
 
+from .. import errors, trace
+from .. import transport as _mod_transport
 from ..tag import Tags
 
-from .. import (
-    errors,
-    trace,
-    transport as _mod_transport,
-    )
-
 
 class BasicTags(Tags):
-    """Tag storage in an unversioned branch control file.
-    """
+    """Tag storage in an unversioned branch control file."""
 
     def set_tag(self, tag_name, tag_target):
         """Add a tag definition to the branch.
@@ -47,12 +40,12 @@ class BasicTags(Tags):
             self._set_tag_dict(td)
 
     def lookup_tag(self, tag_name):
-        """Return the referent string of a tag"""
+        """Return the referent string of a tag."""
         td = self.get_tag_dict()
         try:
             return td[tag_name]
-        except KeyError:
-            raise errors.NoSuchTag(tag_name)
+        except KeyError as e:
+            raise errors.NoSuchTag(tag_name) from e
 
     def get_tag_dict(self):
         with self.branch.lock_read():
@@ -60,22 +53,22 @@ class BasicTags(Tags):
                 tag_content = self.branch._get_tags_bytes()
             except _mod_transport.NoSuchFile:
                 # ugly, but only abentley should see this :)
-                trace.warning('No branch/tags file in %s.  '
-                              'This branch was probably created by bzr 0.15pre.  '
-                              'Create an empty file to silence this message.'
-                              % (self.branch, ))
+                trace.warning(
+                    "No branch/tags file in {}.  "
+                    "This branch was probably created by bzr 0.15pre.  "
+                    "Create an empty file to silence this message.".format(self.branch)
+                )
                 return {}
             return self._deserialize_tag_dict(tag_content)
 
     def delete_tag(self, tag_name):
-        """Delete a tag definition.
-        """
+        """Delete a tag definition."""
         with self.branch.lock_write():
             d = self.get_tag_dict()
             try:
                 del d[tag_name]
-            except KeyError:
-                raise errors.NoSuchTag(tag_name)
+            except KeyError as e:
+                raise errors.NoSuchTag(tag_name) from e
             master = self.branch.get_master_branch()
             if master is not None:
                 try:
@@ -85,7 +78,7 @@ class BasicTags(Tags):
             self._set_tag_dict(d)
 
     def _set_tag_dict(self, new_dict):
-        """Replace all tag definitions
+        """Replace all tag definitions.
 
         WARNING: Calling this on an unlocked branch will lock it, and will
         replace the tags without warning on conflicts.
@@ -95,21 +88,21 @@ class BasicTags(Tags):
         return self.branch._set_tags_bytes(self._serialize_tag_dict(new_dict))
 
     def _serialize_tag_dict(self, tag_dict):
-        td = dict((k.encode('utf-8'), v)
-                  for k, v in tag_dict.items())
+        td = {k.encode("utf-8"): v for k, v in tag_dict.items()}
         return bencode.bencode(td)
 
     def _deserialize_tag_dict(self, tag_content):
-        """Convert the tag file into a dictionary of tags"""
+        """Convert the tag file into a dictionary of tags."""
         # was a special case to make initialization easy, an empty definition
         # is an empty dictionary
-        if tag_content == b'':
+        if tag_content == b"":
             return {}
         try:
             r = {}
             for k, v in bencode.bdecode(tag_content).items():
-                r[k.decode('utf-8')] = v
+                r[k.decode("utf-8")] = v
             return r
         except ValueError as e:
-            raise ValueError("failed to deserialize tag dictionary %r: %s"
-                             % (tag_content, e))
+            raise ValueError(
+                "failed to deserialize tag dictionary {!r}: {}".format(tag_content, e)
+            ) from e
