@@ -1259,8 +1259,16 @@ class InterLocalGitRemoteGitBranch(InterGitBranch):
                 refs[tag_name_to_ref(name)] = sha
             return refs
 
+        # Wrapper to adapt dulwich Repo.generate_pack_data signature for dulwich >= 0.22
+        # Client expects: (have, want, ofs_delta)
+        # Repo provides: (have, want, progress=None, ofs_delta=None)
+        def generate_pack_data_wrapper(have, want, ofs_delta=True):
+            return self.source.repository._git.generate_pack_data(
+                have, want, progress=None, ofs_delta=ofs_delta
+            )
+
         dw_result = self.target.repository.send_pack(
-            get_changed_refs, self.source.repository._git.generate_pack_data
+            get_changed_refs, generate_pack_data_wrapper
         )
         if dw_result is not None and not isinstance(dw_result, dict):
             error = dw_result.ref_status.get(self.target.ref)
