@@ -366,8 +366,16 @@ class InterToRemoteGitRepository(InterToGitRepository):
 
         self._warn_slow()
         with self.source_store.lock_read():
+            # Wrapper to adapt generate_lossy_pack_data signature for dulwich >= 0.22
+            # Client expects: (have, want, ofs_delta)
+            # Method provides: (have, want, shallow=None, progress=None, get_tagged=None, ofs_delta=False)
+            def generate_pack_data_wrapper(have, want, ofs_delta=True):
+                return self.source_store.generate_lossy_pack_data(
+                    have, want, shallow=None, progress=None, get_tagged=None, ofs_delta=ofs_delta
+                )
+
             result = self.target.send_pack(
-                git_update_refs, self.source_store.generate_lossy_pack_data
+                git_update_refs, generate_pack_data_wrapper
             )
             for ref, error in result.ref_status.items():
                 if error:
@@ -408,7 +416,7 @@ class InterFromGitRepository(InterRepository):
     def get_determine_wants_heads(self, wants, include_tags=False, tag_selector=None):
         wants = set(wants)
 
-        def determine_wants(refs):
+        def determine_wants(refs, depth=None):
             unpeel_lookup = {}
             for k, v in refs.items():
                 if k.endswith(PEELED_TAG_SUFFIX):
@@ -431,7 +439,7 @@ class InterFromGitRepository(InterRepository):
 
         return determine_wants
 
-    def determine_wants_all(self, refs):
+    def determine_wants_all(self, refs, depth=None):
         raise NotImplementedError(self.determine_wants_all)
 
     @staticmethod
@@ -487,7 +495,7 @@ class InterGitNonGitRepository(InterFromGitRepository):
                 revids[revid] = sha
         return {revids[r] for r in self.target.has_revisions(revids)}
 
-    def determine_wants_all(self, refs):
+    def determine_wants_all(self, refs, depth=None):
         potential = set()
         for k, v in refs.items():
             # For non-git target repositories, only worry about peeled
@@ -754,7 +762,7 @@ class InterGitGitRepository(InterFromGitRepository):
         )
 
     def get_determine_wants_branches(self, branches, include_tags=False):
-        def determine_wants(refs):
+        def determine_wants(refs, depth=None):
             ret = []
             for name, value in refs.items():
                 if value == ZERO_SHA:
@@ -769,7 +777,7 @@ class InterGitGitRepository(InterFromGitRepository):
 
         return determine_wants
 
-    def determine_wants_all(self, refs):
+    def determine_wants_all(self, refs, depth=None):
         potential = {
             v
             for k, v in refs.items()
@@ -868,8 +876,16 @@ class InterLocalGitRemoteGitRepository(InterToGitRepository):
                 ret[name] = gitid
             return ret
 
+        # Wrapper to adapt dulwich Repo.generate_pack_data signature for dulwich >= 0.22
+        # Client expects: (have, want, ofs_delta)
+        # Repo provides: (have, want, progress=None, ofs_delta=None)
+        def generate_pack_data_wrapper(have, want, ofs_delta=True):
+            return self.source._git.generate_pack_data(
+                have, want, progress=None, ofs_delta=ofs_delta
+            )
+
         new_refs = self.target.send_pack(
-            git_update_refs, self.source._git.generate_pack_data
+            git_update_refs, generate_pack_data_wrapper
         )
         return None, self.old_refs, new_refs
 
