@@ -16,7 +16,6 @@
 
 """Remote dirs, repositories and branches."""
 
-import gzip
 import re
 
 from dulwich.refs import SymrefLoop
@@ -61,7 +60,6 @@ from dulwich.pack import (
     load_pack_index,
     pack_objects_to_data,
 )
-from dulwich.protocol import ZERO_SHA
 from dulwich.refs import SYMREF, DictRefsContainer
 from dulwich.repo import NotGitRepository
 
@@ -77,7 +75,7 @@ from .errors import GitSmartRemoteNotSupported
 from .mapping import encode_git_path, mapping_registry
 from .object_store import get_object_store
 from .push import remote_divergence
-from .refs import branch_name_to_ref, is_peeled, ref_to_tag_name, tag_name_to_ref
+from .refs import is_peeled, ref_to_tag_name, tag_name_to_ref
 from .repository import GitRepository, GitRepositoryFormat
 
 # urlparse only supports a limited number of schemes by default
@@ -175,7 +173,7 @@ def parse_git_error(url, message):
         return PermissionDenied(url, message)
     m = re.match(r"Permission to ([^ ]+) denied to ([^ ]+)\.", message)
     if m:
-        return PermissionDenied(m.group(1), "denied to %s" % m.group(2))
+        return PermissionDenied(m.group(1), "denied to {}".format(m.group(2)))
     if message == "Host key verification failed.":
         return TransportError("Host key verification failed")
     if message == "[Errno 104] Connection reset by peer":
@@ -301,7 +299,7 @@ class DulwichSSHVendor(dulwich.client.SSHVendor):
         if kind == "socket":
             return SSHSocketWrapper(io_object)
         else:
-            raise AssertionError("Unknown io object kind %r'" % kind)
+            raise AssertionError("Unknown io object kind {!r}'".format(kind))
 
 
 # dulwich.client.get_ssh_vendor = DulwichSSHVendor
@@ -611,7 +609,10 @@ class RemoteGitDir(GitDir):
         if self._refs is not None:
             return self._refs
         result = self.fetch_pack(
-            lambda x: None, None, lambda x: None, lambda x: trace.mutter("git: %s" % x)
+            lambda x: None,
+            None,
+            lambda x: None,
+            lambda x: trace.mutter("git: {}".format(x)),
         )
         self._refs = remote_refs_dict_to_container(result.refs, result.symrefs)
         return self._refs
@@ -704,7 +705,7 @@ class RemoteGitDir(GitDir):
 
         with source_store.lock_read():
 
-            def generate_pack_data(have, want, progress=None, ofs_delta=True):
+            def generate_pack_data(have, want, ofs_delta=True, progress=None):
                 git_repo = getattr(source.repository, "_git", None)
                 if git_repo:
                     shallow = git_repo.get_shallow()
@@ -847,7 +848,7 @@ class BzrGitHttpClient(dulwich.client.HttpGitClient):
             raise NotGitRepository()
         elif response.status != 200:
             raise GitProtocolError(
-                "unexpected http resp %d for %s" % (response.status, url)
+                f"unexpected http resp {response.status} for {url}",
             )
 
         read = response.read
@@ -1160,7 +1161,9 @@ class RemoteGitBranch(GitBranch):
         self._sha = sha
 
 
-def remote_refs_dict_to_container(refs_dict, symrefs_dict={}):
+def remote_refs_dict_to_container(refs_dict, symrefs_dict=None):
+    if symrefs_dict is None:
+        symrefs_dict = {}
     base = {}
     peeled = {}
     for k, v in refs_dict.items():
